"""

this tool helps viewing VOC format data


"""
import os
import sys
import cv2
import xml.etree.ElementTree as ET
from glob import glob
import os
import sys
import cv2
from alfred.utils.log import logger as logging


def get_and_check(root, name, length):
    vars = root.findall(name)
    if len(vars) == 0:
        raise NotImplementedError('Can not find %s in %s.' % (name, root.tag))
    if length > 0 and len(vars) != length:
        raise NotImplementedError('The size of %s is supposed to be %d, but is %d.' % (name, length, len(vars)))
    if length == 1:
        vars = vars[0]
    return vars


def get(root, name):
    vars = root.findall(name)
    return vars


def vis_voc(img_root, label_root):
    logging.info('img root: {}, label root: {}'.format(img_root, label_root))
    # auto detection .jpg or .png images
    img_files = glob(os.path.join(img_root, '*.[jp][pn]g'))
    for img_f in img_files:
        if os.path.exists(img_f):
            img = cv2.imread(img_f)
            label_path = os.path.join(label_root, os.path.basename(img_f).split('.')[0] + '.xml')
            if os.path.exists(label_path):
                #
                tree = ET.parse(label_path)
                root = tree.getroot()
                for obj in get(root, 'object'):
                    category = get_and_check(obj, 'name', 1).text
                    bndbox = get_and_check(obj, 'bndbox', 1)
                    xmin = int(float(get_and_check(bndbox, 'xmin', 1).text))
                    ymin = int(float(get_and_check(bndbox, 'ymin', 1).text))
                    xmax = int(float(get_and_check(bndbox, 'xmax', 1).text))
                    ymax = int(float(get_and_check(bndbox, 'ymax', 1).text))

                    cv2.putText(img, category, (xmin, ymin), cv2.FONT_HERSHEY_COMPLEX, 0.7, (255, 255, 255))
                    cv2.rectangle(img, (xmin, ymin), (xmax, ymax), (0, 255, 0), 2, 1)
                cv2.imshow('voc check', img)
                cv2.waitKey(0)
            else:
                logging.warning('xxxx image: {} according label: {} not found.'.format(img_f, label_path))


if __name__ == "__main__":
    vis_voc(sys.argv[1], sys.argv[2])



# -*- coding: utf-8 -*-
# file: tests.py
# author: JinTian
# time: 16/03/2018 3:23 PM
# Copyright 2018 JinTian. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ------------------------------------------------------------------------
from utils.mana import welcome

from utils.log import logger as logging
from vis.image.det import visualize_det_cv2
import cv2
import numpy as np
from vis.image.get_dataset_label_map import coco_label_map_list


if __name__ == '__main__':
    welcome('')
    logging.info('hi hiu')
    logging.error('ops')

    a = cv2.imread('/home/jintian/Pictures/1.jpeg')

    dets = [
        [1, 0.9, 4, 124, 333, 256],
        [2, 0.7, 155, 336, 367, 485],
    ]
    dets = np.array(dets)
    print(type(a))
    visualize_det_cv2(a, dets, coco_label_map_list, is_show=True)


"""
gather all voc labels from Annotations root folder
which contains all xml annotations

"""

"""

gather the label from Annotations
"""
import os
import pickle
import os.path
import sys
import numpy as np
if sys.version_info[0] == 2:
    import xml.etree.cElementTree as ET
else:
    import xml.etree.ElementTree as ET
import glob



def gather_labels(anno_dir):
    all_labels = glob.glob(os.path.join(anno_dir, '*.xml'))
    all_names = []
    for label in all_labels:
        print('parsing {}'.format(label))
        root = ET.parse(label).getroot()
        for obj in root.iter('object'):
            name = obj.find('name').text.lower().strip()
            print(name)
            if name not in all_names:
                all_names.append(name)
    print('Done. summary...')
    print('all {} classes.'.format(len(all_names)))
    print(all_names)





import os


def mute_tf():
    """
    this function will mute tensorflow
    disable tensorflow logging information
    call this before you import tensorflow
    """
    os.environ['TF_CPP_MIN_LOG_LEVEL'] = '3'